#
# spec file for package gtranslator
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gtranslator
Version:        41.0
Release:        bp156.2.7
Summary:        A gettext po file editor for the GNOME desktop
License:        GPL-3.0-or-later
Group:          Development/Tools/Other
URL:            https://wiki.gnome.org/Apps/Gtranslator
Source0:        https://download.gnome.org/sources/gtranslator/41/%{name}-%{version}.tar.xz
Source99:       gtranslator-rpmlintrc
# PATCH-FIX-UPSTREAM 7ac572cc8c8c37ca3826ecf0d395edd3c38e8e22.patch -- Fix build with meson 0.61 and newer
Patch1:         https://gitlab.gnome.org/GNOME/gtranslator/-/commit/7ac572cc8c8c37ca3826ecf0d395edd3c38e8e22.patch

BuildRequires:  fdupes
BuildRequires:  gettext-tools
BuildRequires:  intltool
BuildRequires:  itstool
BuildRequires:  meson >= 0.46.0
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gio-2.0) >= 2.36.0
BuildRequires:  pkgconfig(glib-2.0) >= 2.36.0
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gspell-1) >= 1.2.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.20
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(gtksourceview-4) >= 4.0.2
BuildRequires:  pkgconfig(iso-codes)
BuildRequires:  pkgconfig(json-glib-1.0) >= 1.2.0
BuildRequires:  pkgconfig(libdazzle-1.0) >= 3.33.90
BuildRequires:  pkgconfig(libgda-6.0) >= 6.0.0
BuildRequires:  pkgconfig(libhandy-1)
BuildRequires:  pkgconfig(libsoup-2.4)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.4.12
Requires:       gsettings-desktop-schemas
Requires:       iso-codes
Requires:       libgda-sqlite >= 6.0.0
Obsoletes:      gtranslator-devel <= 2.91.7

%description
Gtranslator is a ".po" file editor with many bells and whistles.
It features many functions which aid in the work of translators of po
files imminently.

%package doc
Summary:        Documentation for %{name}
Group:          Development/Tools/Other

%description doc
This package contains documentation for %{name}.

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-D gtk_doc=true
%meson_build

%install
%meson_install
find %{buildroot} -type f -name "gtr-marshal.h" -delete -print
%find_lang %{name}
%fdupes %{buildroot}%{_prefix}

%files
%license COPYING
%doc README.md
%{_mandir}/man?/*
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/*.desktop
%{_datadir}/glib-2.0/schemas/*.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.Gtranslator*.svg
%{_datadir}/metainfo/org.gnome.Gtranslator.appdata.xml

%files doc
%doc AUTHORS MAINTAINERS NEWS THANKS
%doc %{_datadir}/gtk-doc/html/%{name}/

%files lang -f %{name}.lang

%changelog
* Tue Feb 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 41.0:
  + Allow adding comments when uploading to l10n.gnome.org.
  + Updated translations.
- Drop patch fixed upstream: libgda-6.patch
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 7ac572cc8c8c37ca3826ecf0d395edd3c38e8e22.patch: Fix build
  with meson 0.61 and newer.
- Drop update-desktop-files BuildRequires and macro, no longer
  needed.
* Mon Apr  5 2021 Callum Farmer <gmbr3@opensuse.org>
- Update to version 40.0:
  + Add libhandy widgets to improve the user interface for
    different sizes.
  + Add new integration with l10n.gnome.org so now it's possible
    to reserve a file and upload using the desktop app.
- Add pkgconfig(libhandy-1) BuildRequires: New dependency.
- Remove gtranslator-remove-statusbar.patch: merged
- Add libgda-6.patch: support GDA 6
* Thu Oct  8 2020 malcolmlewis@opensuse.org
- Add gtranslator-remove-statusbar.patch: Remove leftovers of
  statusbar, (glgo#GNOME/gtranslator!70).
* Mon Oct  5 2020 dimstar@opensuse.org
- Update to version 3.38.0:
  + Add save file dialog when open from DL.
  + Enable wrap-around by default in search bar.
  + search-bar: error style when not found.
  + Use base language to get the plural form on assistant.
  + Download DL files to Download folder.
  + Use GtkFileChooserNative for open and save dialogs.
  + Editor font configurable on preferences.
* Sat Mar 14 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + New search/replace popover.
  + Open from DL button.
  + Help doc improvements.
  + Fix profile edit and remove.
  + Updated translations.
- Add pkgconfig(libdazzle-1.0) BuildRequires: New dependency.
- Split out doc subpackage.
- Add gtranslator-rpmlintrc as source. Filter obsolete not provided
  gtranslator-devel warning, the Obsolete without Provides is
  intentional.
* Sat Mar 14 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.34.0:
  + Updated translations.
- Changes from version 3.33.90:
  + DL initial integration.
  + Fixes in the search dialog.
* Thu Jan 30 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Sun Jul  7 2019 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of description.
* Tue Jun 18 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Run spec-cleaner, modernize spec.
- Drop obsolete glib2_gsettings_schema_requires,
  glib2_gsettings_schema_post(un), desktop_database_post(un) and
  icon_theme_cache_post(un) macros, no longer needed as
  file-triggers takes care of this now.
- Drop ldconfig call.
- Obsolete no longer present devel sub-package.
* Sat May 25 2019 Dingzhong Chen <wsxy162@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
- Changes from version 3.31.90:
  + XML language syntax for the source view
  + Fix msg status management
  + Use theme_fg_color for translated texts
  + Better prj id version default header
  + Header with default values when doesn't exists
  + codeview: Recover codeview plugin
  + Show context in the original message bar
  + List of languages in a config file instead iso-codes
  + Find & replace and copy text to shortcuts window
  + Ctrl+space to copy original text into translated
  + Native File Chooser for the translation memory
- Changes from version 3.30.1:
  + Fix locale lookup dir
  + Added itstool dependency to Meson
  + Fix loading help
  + New interface image in help
  + Updated translations.
- Changes from version 3.30.0:
  + Full interface redesign to acomplish gnome 3 HIG
  + Fix bug in find & replace that marks all fuzzy as translated
  + Autofill profile based on language
  + A lot of bug fixes
  + Remove plugin system
- Clean up spec file
  + Update Summary & Url
  + Switch to Meson build system
* Thu Sep 14 2017 zaitor@opensuse.org
- Conditionalize pkgconfig(gdict-1.0) BuildRequires, only available
  on older versions of openSUSE, gnome-dictionary 3.26.0 made this
  symbol private.
* Thu Jun  1 2017 dimstar@opensuse.org
- Inject -Wno-error=format-nonliteral into CFLAGS: fix build with
  GCC 7 (boo#1041213).
* Wed Mar 18 2015 zaitor@opensuse.org
- Own appdata dir on older versions of openSUSE.
* Mon Mar 16 2015 dimstar@opensuse.org
- Update to version 2.91.7:
  + Misc bugfixes.
  + Updated translations.
- Drop gtranslator-gtkspell3.patch: fixed upstream.
- Drop gnome-common BuildRequires and call to autoreconf, as we no
  longer carry any patches.
* Sat Jun  7 2014 stathisagrapidis@gmail.com
- Add missing libgda-5_0-sqlite runtime dependency. Fix bnc#780249.
* Thu Mar 21 2013 dimstar@opensuse.org
- Port to gtkspell3:
  + Add gtranslator-gtkspell3.patch
  + Replace pkgconfig(gtkspell-3.0) BuildRequires with
    pkgconfig(gtkspell3-3.0).
  + Add gnome-common BuildRequires and call to autoreconf, as above
    patch touches the build system.
* Fri Jan  4 2013 dimstar@opensuse.org
- Update to version 2.91.6:
  + Misc bugfixes.
  + Updated translations.
- Drop gtranslator-gdl362.patch: fixed upstream.
- Replace gnome-doc-utils-devel BuildRequires with yelp-tools,
  following upstreams port to the new documentation infrastructure.
* Mon Nov 26 2012 dimstar@opensuse.org
- Add gtranslator-gdl362.patch: Fix build with gdl 3.6.2.
* Sun Jun 17 2012 badshah400@gmail.com
- Update to version 2.91.5:
  + Add/update X-Generator header in PO file
  + Misc bug fixes
  + Updated translations
- No longer install anything in %%{_datadir}/pixmaps/%%{name}/.
* Mon May 14 2012 vuntz@opensuse.org
- Update to version 2.91.4:
  + Add app menu
  + Move libgtranslator-private library to pkglibdir
  + Better handling of the table message
  + Update TM when a new po file is loaded
  + Try using Content-Type charset if the file is not UTF-8
  + Remove ok/cancel buttons to add new comments
  + Fix a crash when dropping an item to the toolbar
  + Misc bugfixes
  + Updated translations.
* Wed Apr 25 2012 vuntz@opensuse.org
- Update to version 2.91.3:
  + Port to GResource
  + Misc bugfixes
  + Updated translations.
* Tue Apr 10 2012 vuntz@opensuse.org
- Update to version 2.91.2:
  + Use new libpeas API
  + Complete list of plural forms
  + Misc bugfixes
  + Updated translations.
* Wed Mar 28 2012 vuntz@opensuse.org
- Update to version 2.91.1:
  + Make translation memory a standalone plugin
  + Misc bugfixes
  + Updated translations.
* Tue Feb  7 2012 zaitor@opensuse.org
- Update to version 2.90.8:
  + Make it build with latest GTK+.
  + Add support for gda 5.
  + Misc bugfixes.
  + Updated translations.
- Drop patches fixed upstream:
  + gtranslator-libgda-5.0.patch
  + gtranslator-gtkspell3.patch
- Remove gnome-common BuildRequires and gnome-autogen.sh call: we
  don't carry any patches touching the build system anymore.
* Wed Oct 19 2011 zaitor@opensuse.org
- Update to version 2.90.7:
  + Relicense some files as GPLv3+.
  + Don't normalize translations stored in the translation memory.
  + Update translation.
* Wed Oct 12 2011 vuntz@opensuse.org
- Update to version 2.90.6:
  + Misc bugfixes.
  + Updated translations.
- Rebase gtranslator-libgda-5.0.patch and
  gtranslator-gtkspell3.patch.
- Change --with-gtkspell configure option to --with-gtkspell3,
  following upstream change.
* Thu Oct  6 2011 vuntz@opensuse.org
- Add iso-codes Requires since the iso-codes data is used at
  runtime.
* Mon Sep 26 2011 gankov@opensuse.org
- Add support spell check with gtkspell3.
  + Add gtranslator-gtkspell3.patch: add support for gtkspell3.
  + Change pkgconfig(gtkspell-2.0) BuildRequires to
    pkgconfig(gtkspell-3.0) so we can build with the new gtkspell.
* Wed Jun 15 2011 dimstar@opensuse.org
- Add optional port to libgda 5.0:
  + Add gtranslator-libgda-5.0.patch: add support for libgda-5.0
    with a new --with-gda parameter.
  + Add gnome-common BuildRequires and call to gnome-autogen.sh,
    needed for the patch to be taken into account.
  + Replace pkgconfig(libgda-4.0) BuildRequires with libgda-devel:
    this allows us to use libgda-4.0 and libgda-5.0 without
    knowledge of what version is in the repository.
  + Pass --with-gda=4.0|5.0 to configure: the version (4.0 or 5.0)
    is extracted from the rpm database, based on the libgda-devel
    package that has been installed.
* Wed Jun 15 2011 vuntz@opensuse.org
- Update to version 2.90.5:
  + Misc bugfixes
  + Updated translations.
* Tue May 24 2011 dimstar@opensuse.org
- Update to version 2.90.4:
  + Misc bugfixes
- Changes from version 2.90.3:
  + Put the gdl container inside the tab
  + Add a tab activatable extension point
- Changes from version 2.90.2:
  + UI cleanup
- Changes from version 2.90.1:
  + Automatize profile generation
  + Fix preferences dialog space
  + Remove interface tab from preferences dialog
  + Fix remaining issues in the gtk+ 3 port.
- Changes from version 2.90.0:
  + Port to gtk+ 3
  + Port to libpeas
  + Added support for python plugins
  + Ported charmap to python
  + Remove --window-new command line option
  + Port to gsettings
  + Merge insert-tags plugin into insert-params plugin
  + Port to GtkApplication
  + Misc Bugfixes
  + Updated translations.
- Note that gtkspell support is disabled for now because there's no
  gtk3-powered gtkspell.
- Change BuildRequires to pkgconfig()-style and move to GNOME 3:
  + Old ones: gdl-devel, glib2-devel, gnome-utils-devel,
    gtk2-devel, gtksourceview-devel, gtkspell-devel, libgda-devel,
    libxml2-devel.
  + New ones: gdict-1.0, gdl-3.0, glib-2.0, gtk+-3.0,
    gtksourceview-3.0, gtkspell-2.0, libgda-4.0, libxml-2.0.
- Drop no longer needed BuildRequires: gucharmap-devel,
  libsoup-devel, libunique-devel.
- Add new BuildRequires: pkgconfig(iso-codes),
  pkgconfig(json-glib-1.0, pkgconfig(libpeas-1.0),
  pkgconfig(libpeas-gtk-1.0).
- Drop gtranslator-disable-update-db.patch: no longer required.
- Drop gnome-common BuildRequires, gnome-autogen.sh call during
  build and --disable-update-mimedb configure flag: obsoleted.
- Move .gir file to devel subpackage.
- Add call to ldconfig in %%post/%%postun scriptlet because of the
  new library in the package.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Add Recommends for lang subpackage.
* Wed Dec  8 2010 vuntz@opensuse.org
- Update to version 1.9.13:
  + Enable use of local mirrors of open-tran.eu
  + Adapt the OpenTran plugin to the new open-tran.eu API
  + Misc Bugfixes
  + Updated translations.
- Add gtranslator-disable-update-db.patch: add a
  - -disable-update-mimedb configure option to not run
  update-desktop-database on install.
- Pass --disable-update-mimedb to configure.
* Sat Oct  9 2010 vuntz@opensuse.org
- Update to version 1.9.12:
  + Port to GSettings
  + Make it work with GSEAL enabled
  + Misc Bugfixes
  + Updated translations.
- Remove gconf schemas handling:
  + remove gconf2-devel BuildRequires.
  + remove %%gconf_schemas_prereq, %%find_gconf_schemas and
    schemas-related scriptlets.
- Use %%glib2_gsettings_schema_* macros for GSettings schemas.
- Add pkgconfig(gsettings-desktop-schemas) BuildRequires and
  gsettings-desktop-schemas Requires, since the schemas are needed
  at runtime too.
* Fri Aug 13 2010 vuntz@opensuse.org
- Fix license: gtranslator is GPLv3+, not GPLv2+. Fix bnc#595680.
* Thu Aug  5 2010 vuntz@opensuse.org
- Remove unneeded libdb-4_5-devel BuildRequires: it was needed for
  the old memory backend.
- Remove unneeded libneon-devel BuildRequires: this is replaced by
  libsoup now.
- Remove subversion-devel BuildRequires: the subversion plugin is
  gone.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 1.9.11:
  + Add the option to remove entries from the memory translation
  + New memory translation backend using libgda
- Changes from version 1.9.10:
  + Factored out the tab label
  + Make the translation memory always visible
  + Updated translations.
- Add libgda-devel BuildRequires.
* Sun Feb 21 2010 vuntz@opensuse.org
- Update to version 1.9.9:
  + Add Profile quick selector
  + Rewriting profile manager to use GtrProfileManager
  + Converted GtrApplication into an UniqueAPP using libunique
  + Misc bugfixes
  + Updated translations.
- Add libunique-devel BuildRequires.
* Wed Feb 10 2010 vuntz@opensuse.org
- Update to version 1.9.8:
  + Refactor methods and file names from gtranslator to gtr
  + Modernize autotools configuration
  + Added new tango icons and logo
  + Removed Subversion plugin
  + Misc Bugfixes
  + Updated translations.
- Change group from Development/Tools to Development/Tools/Other to
  fix rpmlint warning.
* Sun Jan 31 2010 vuntz@opensuse.org
- Update to version 1.9.7:
  + Show percentage of translated messages
  + Fixed several compiler warnings
  + Update toolbar editor
  + Make header inherit from GtranslatorMsg
  + Ported gtranslator from MessageArea to GtkInfoBar
  + Misc Bugfixes
  + Updated translations.
- Remove renaming of sr@Latn locale to sr@latin.
* Tue Aug 25 2009 vuntz@novell.com
- Update to version 1.9.6:
  + Adapted gtranslator in order to work on Windows
  + bgo#579775 - Fixed format string attack
  + bgo#582430 - Added some header files
  + bgo#555672 - Fixed CRITICAL: editor_create_item_from_name
  + bgo#557096 - Fixed GtkSpinButton problem changing to GtkBuilder
  + bgo#569061 - Displaying an error message before saving a read
    only file
  + bgo#569062 - Use a "standard" tabs menu instead of
    Go->Next/Prev File
  + bgo#569068 - Made more clear the message in the status bar
  + bgo#571497 - Fixed crash on first-time startup with po-file as
    argument
  + bgo#575128 - Removed deprecated GTK+ symbols
  + bgo#579775 - Fixed Format string attack danger
  + bgo#582430 - Some of the header files weren't included in the
    source code
  + bgo#583961 - Fixed to build with gdl 2.27.2
  + bgo#584692 - Show the next message of the one you are editing
  + bgo#591594 - Fixed problem that made Edit header only made
    effect when you close gtranslator
  + bgo#592210 - Removed duplicated define in configure.ac
  + bgo#592214 - Fixed some gcc warnings
  + bgo#592215 - Wrong arguments to
    gtranslator_statusbar_flash_message()
  + bgo#592226 - Fixed Error widget built wrongly
  + bgo#592227 - Source code did not working due to a wrong widget
    name
  + bgo#569054 - Fixed empty line insertion before translator email
    in header
  + Updated translations.
- Drop gtranslator-gdl-2.27.patch and gtranslator-profile.patch:
  fixed upstream.
* Thu Jun 11 2009 vuntz@novell.com
- Add gtranslator-gdl-2.27.patch to fix build with latest gdl.
* Thu May 14 2009 vuntz@novell.com
- Update gtranslator-profile.patch to fix more build issues.
- Add BuildRequires for features: gnome-utils-devel,
  gtkspell-devel, gucharmap-devel, libneon-devel, libsoup-devel,
  subversion-devel
- Pass --disable-static, --with-gtkspell and --with-dictionary to
  configure, and remove --enable-mime-bind and --with-gconf that
  don't exist.
- Clean up file list a bit; do not ship help files twice.
* Thu May 14 2009 vuntz@novell.com
- Initial package.
